<TS language="bg" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Създай нов адрес</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Нов</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Копирай текущо избрания адрес към клипборда</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Копирай</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Изтрий текущо избрания адрес от листа</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Търсене по адрес или име</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Изнеси данните в избрания раздел към файл</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>Изнеси</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Изтрий</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Избери адреса на който да пратиш монети</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Избери адреса на който да получиш монети</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Избери</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Адрес за пращане</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Адрес за получаване</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Тези са вашите Биткойн адреси за изпращане на монети. Винаги проверявайте количеството и получаващия адрес преди изпращане. </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Копирай адрес</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Копирай етикет</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Редактирай</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Изнеси лист с адреси</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>CSV файл (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Изнасянето се провали</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Получи се грешка при запазването на листа с адреси към %1. Моля опитайте пак.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Диалог за пропуск</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Въведи парола</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Нова парола</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Повтори парола</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Показване на парола</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Криптирай портфейл</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Тази операция изисква вашата парола на портфейла за отключването на портфейла.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Отключи портфейла</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Тази операция изисква вашата парола на портфейла за декриптирането на портфейла.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Декриптирай портфейл</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Промени парола</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Потвърди криптирането на порфейла</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>ВНИМАНИЕ: Ако шифрирате вашият портфейл и изгубите паролата си, &lt;b&gt;ЩЕ ИЗГУБИТЕ ВСИЧКИТЕ СИ БИТКОИНИ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Наистина ли желаете да шифрирате портфейла си?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>портфейлa е шифрован</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Въведете новата парола към портфейла.&lt;br/&gt;Моля ползвайте парола съставена от &lt;b&gt;десет или повече произволни символа&lt;/b&gt;, или &lt;b&gt;осем или повече думи&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Въведете старата и новата паролна фраза за портфейла.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Портфейл за криптиране</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Портфейлът ви е на път да бъде шифрован.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Вашият портфейл сега е криптиран.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>ВАЖНО: Всички стари запазвания, които сте направили на Вашият портфейл трябва да замените с запазване на новополучения, шифриран портфейл. От съображения за сигурност, предишните запазвания на нешифрирани портфейли ще станат неизползваеми веднага, щом започнете да използвате новият, шифриран портфейл.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Шифрирането беше неуспешно</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Шифрирането на портфейла беше неуспешно, поради софтуерен проблем. Портфейлът не е шифриран.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Паролите не съвпадат</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Отключването не бе успешно</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Паролата въведена за дешифриране на портфейла е грешна.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Отключването не бе успешно</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Паролата на портфейла беше променена успешно.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Внимание:Бутонът Caps Lock е включен.</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Мрежова маска</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Блокиран до</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Подпиши съобщение...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Синхронизиране с мрежата...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Покажи общ преглед на портфейла</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>Транзакции</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Разгледай история на транзакциите</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Излез от приложението</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>За %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Покажи информация за %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Относно Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Покажи информация отностно Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Промени конфигурации за %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Криптирай портфейл</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Направи резервно копие на портфейла...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Промени паролата...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Отвори URI</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>Създай портфейл...</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>Създай нов портфейл</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Портфейл</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation>Мрежата деактивирана</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Синхронизиране на хедъри (%1%)</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Повторно индексиране на блоковете на диска...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Изпращане към Биткоин адрес</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Запазване на портфейла на друго място</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Променя паролата за портфейла</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Проверка на съобщение...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;изпращам</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;получавам</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Показване / Скриване</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Показване и скриване на основния прозорец</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Шифроване на личните ключове,които принадлежат на портфейла Ви.</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Пишете съобщения със своя Биткойн адрес за да докажете,че е ваш.</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Потвърждаване на съобщения  за да се знае,че са написани с дадените Биткойн адреси.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощ</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Лентата с инструменти</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Изискване на плащания(генерира QR кодове и биткойн: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Показване на списъка с използвани адреси и имена</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Покажи списък с използваните адреси и имена.</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Налични команди</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Индексиране на блокове на диска...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Обработване на блокове на диска...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>Преработен %n блок от историята с транзакции.</numerusform><numerusform>Преработени %n блокове от историята с транзакции.</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 зад</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Последния получен блок е генериран преди %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Транзакции след това няма все още да бъдат видими.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>грешка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Актуално</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>Прозорец на възела</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Отворете конзолата за диагностика и отстраняване на грешки</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Изпращане на адресите</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Получаване на адресите</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Отворете портфейл</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>Затвори Портфейла</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>Затвори портфейла</translation>
    </message>
    <message>
        <source>Close All Wallets...</source>
        <translation>Затвори Всички Портфейли...</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Затвори всички портфейли</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>Покажи %1 помощно съобщение за да получиш лист с възможни Биткойн команди</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Прозорец</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Минимизирай</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Увеличи</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>Главен Прозорец</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 клиент</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished"><numerusform>%n активна връзка към Биткойн мрежата</numerusform><numerusform>%n активни връзки към Биткойн мрежата</numerusform><numerusform>%n активна връзка към Биткойн мрежата</numerusform><numerusform>%n активни връзки към Биткойн мрежата</numerusform></translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Свързване с пиъри</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Наваксвам</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Дата: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Сума: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Тип: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Етикет: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Адрес: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Изпратена транзакция</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Входяща транзакция</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Портфейлът е &lt;b&gt;криптиран&lt;/b&gt; и &lt;b&gt;отключен&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Портфейлът е &lt;b&gt;криптиран&lt;/b&gt; и &lt;b&gt;заключен&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Избор на монети</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтове:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Такса:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>прах:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>След такса:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Промяна:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(Пре)махни всички</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Дървовиден режим</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>списък Режим</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Количество</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Получени с име</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Получени с адрес</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>потвърждения</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Потвърдено</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Копиране на сумата</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Копирайте адреса</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Копиране на &amp;етикета</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation>Копиране на &amp;сумата</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation>&amp;Копиране на &amp;ID на транзакцията</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation>&amp;Заключи неусвоени</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Отключете неизползваните</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Копиране на количеството</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Копирай такса</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Копирайте след такса</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Копиране на байтовете</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Копирай прахта:</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Промяна на копирането</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 заключен)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>да</translation>
    </message>
    <message>
        <source>no</source>
        <translation>не</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Този етикет става червен ако някой получател получи количество, по-малко от текущия праг на прах</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>ресто от %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(промени)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation>Създайте портфейл</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation>Създаването на портфейл не бе успешен</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation>Създайте портфейл</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>портфейл</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Шифриране на портфейла</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Редактирайте адреса</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Име</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Етикетът свързан с това въведение в листа с адреси</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Адресът свързан с това въведение в листа с адреси. Това може да бъде променено само за адреси за изпращане.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Адрес</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Нов адрес за изпращане</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Редактиране на получаващия адрес</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Редактиране на адрес за изпращане</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>"%1" не е валиден Биткоин адрес.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Не може да отключите портфейла.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Създаването на ключ беше неуспешно.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Ще се създаде нова папка за данни.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>име</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Директорията вече съществува.Добавете %1 ако желаете да добавите нова директория тук.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Пътят вече съществува и не е папка.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Не може да се създаде директория тук.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>версия</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Относно %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Списък с команди</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Добре дошли</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Добре дошли в %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Програмата се стартира за първи път вие може да изберете къде %1 ще се запаметят данните.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Използване на директория по подразбиране</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Използване на директория ръчно</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Биткоин</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Най малко %1 GB данни ще бъдат запаметени в тази директория, и ще нарастват през времето.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation>Около %1 GB данни ще бъдат запаметени в тази директория.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>грешка</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n GB свободно пространство на разположение</numerusform><numerusform>%n GB свободно пространство на разположение</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation><numerusform>(%n GB е нужен)</numerusform><numerusform>(%n GB са нужни)</numerusform></translation>
    </message>
    </context>
<context>
    <name>MempoolStats</name>
    <message>
        <source>N/A</source>
        <translation>Несъществуващ</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>форма</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation type="unfinished">Неизвестен...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Време на последния блок</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>прогрес</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>изчисляване</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Скрий</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Адрес</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Вмъкни от клипборда</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>Портфейл по подразбиране</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>Отворете портфейл</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Настроики</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Основни</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Размер на кеша в &amp;базата данни</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Брой на скриптове и &amp;нишки за потвърждение</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>IP адрес на прокси (напр. за IPv4: 127.0.0.1 / за IPv6: ::1)</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Отворете конфигурационния файл</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Възстановете всички настройки по подразбиране.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Нулирай настройките</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Мрежа</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>По&amp;ртфейл</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Експерт</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>Позволяване на монетите и &amp;техните възможности</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;Похарчете непотвърденото ресто</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Автоматично отваряне на входящия Bitcoin порт. Работи само с рутери поддържащи UPnP.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Отваряне на входящия порт чрез &amp;UPnP</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation>Позволи външни връзки</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation>Позволи входящи връзки</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation>Свързване с Биткойн мрежата чрез SOCKS5  прокси.</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation>&amp;Свързване чрез SOCKS5  прокси (прокси по подразбиране):</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Прокси &amp; АйПи:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Порт на прокси сървъра (пр. 9050)</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Тор</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Прозорец</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>След минимизиране ще е видима само иконата в системния трей.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Минимизиране в системния трей</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>М&amp;инимизиране при затваряне</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Интерфейс</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Език:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Мерна единица за показваните суми:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Изберете единиците, показвани по подразбиране в интерфейса.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>Дали да покаже възможностите за контрол на монетите или не.</translation>
    </message>
    <message>
        <source>&amp;Third party transaction URLs</source>
        <translation type="unfinished">&amp;URL адреси на трети страни</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>default</source>
        <translation>подразбиране</translation>
    </message>
    <message>
        <source>none</source>
        <translation>нищо</translation>
    </message>
    <message>
        <source>Bitcoin Core</source>
        <translation>Биткойн ядро</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Потвърдете опциите за нулиране</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Изисква се рестартиране на клиента за активиране на извършените промени.</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <translation>Клиентът ще бъде изключен. Искате ли да продължите?</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Опции за конфигуриране</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>грешка</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Тази промяна изисква рестартиране на клиента Ви.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Текущият прокси адрес е невалиден.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>форма</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Текущата информация на екрана може да не е актуална. Вашият портфейл ще се синхронизира автоматично с мрежата на Биткоин, щом поне една връзката с нея се установи; този процес все още не е приключил.</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation>Гледайте само:</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>На разположение:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Текущото Ви разходоносно салдо</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>В очакване на:</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Незрялото:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Миниран баланс,който все още не се е развил</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>баланс</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Обща сума:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Текущото Ви общо салдо</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>За харчене:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Последни транзакции</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Затвори</translation>
    </message>
    <message>
        <source>or</source>
        <translation>или</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Възникна грешка по време назаявката за плащане</translation>
    </message>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation>Биткойн не можe да се стартира: click-to-pay handler</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Справяне с URI</translation>
    </message>
    <message>
        <source>Invalid payment address</source>
        <translation>Невалиден адрес на плащане</translation>
    </message>
    <message>
        <source>Payment request file handling</source>
        <translation>Файл за справяне със заявки</translation>
    </message>
</context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Потребителски агент</translation>
    </message>
    <message>
        <source>Ping</source>
        <translation>пинг</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Изпратени</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Получени</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Количество</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation>Въведете Биткойн адрес (например: %1)</translation>
    </message>
    <message>
        <source>Inbound</source>
        <translation>Входящи</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation>%1 ден</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 час</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 минута</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation>%1 секунда</translation>
    </message>
    <message>
        <source>None</source>
        <translation>нито един</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Несъществуващ</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation>%1 милисекунда</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n час</numerusform><numerusform>%n часа</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n ден</numerusform><numerusform>%n дни</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n седмица</numerusform><numerusform>%n седмици</numerusform></translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 и %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n година</numerusform><numerusform>%n години</numerusform></translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 Байт</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 Килобайт</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 Мегабайт</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 Гигабайт</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" does not exist.</source>
        <translation>Грешка:Избраната "%1" директория не съществува.</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>неизвестен</translation>
    </message>
    <message>
        <source>Blk</source>
        <comment>Tx Watch: Block type abbreviation</comment>
        <translation>блок</translation>
    </message>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>Транзакция</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Запиши изображение...</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Копирай изображение</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Грешка при създаването на QR Code от URI.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Запази QR Код</translation>
    </message>
    <message>
        <source>PNG Image (*.png)</source>
        <translation>PNG Изображение (*.png)</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Несъществуващ</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Клиентска версия</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>Данни</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общ</translation>
    </message>
    <message>
        <source>Using BerkeleyDB version</source>
        <translation>Използване на база данни BerkeleyDB </translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Време за стартиране</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>мрежа</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>име</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Брой връзки</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Портфейл: </translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Получени</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Изпратени</translation>
    </message>
    <message>
        <source>&amp;Peers</source>
        <translation>&amp;Пиъри</translation>
    </message>
    <message>
        <source>Select a peer to view detailed information.</source>
        <translation>Избери пиър за детайлна информация.</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Потребителски агент</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>Прозорец на възела</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Услуги</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation>Продължителност на връзката</translation>
    </message>
    <message>
        <source>Last Send</source>
        <translation>Изпратени за последно</translation>
    </message>
    <message>
        <source>Last Receive</source>
        <translation>Получени за последно</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation>Време за отговор</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Време на последния блок</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Отвори</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Конзола</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Мрежов Трафик</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Входящи:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Изходящи</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Лог файл,съдържащ грешките</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Изчисти конзолата</translation>
    </message>
    <message>
        <source>To</source>
        <translation>към</translation>
    </message>
    <message>
        <source>From</source>
        <translation>от</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Не</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Копирайте адреса</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation>Мрежата деактивирана</translation>
    </message>
    <message>
        <source>via %1</source>
        <translation>посредством %1</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестен</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Сума</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Име:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Съобщение:</translation>
    </message>
    <message>
        <source>Use this form to request payments. All fields are &lt;b&gt;optional&lt;/b&gt;.</source>
        <translation>Използвате този формуляр за заявяване на плащания. Всички полета са &lt;b&gt;незадължителни&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>An optional amount to request. Leave this empty or zero to not request a specific amount.</source>
        <translation>Незадължително заявяване на сума. Оставете полето празно или нулево, за да не заявите конкретна сума.</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Изискване на плащане</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Изчисти всички полета от формуляра.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Изчистване</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation>Изискана история на плащанията</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Показване</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Премахване</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Копиране на &amp;URI</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Копирайте адреса</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Копиране на &amp;етикета</translation>
    </message>
    <message>
        <source>Copy &amp;message</source>
        <translation type="unfinished">&amp;Копиране на съобщението</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation>Копиране на &amp;сумата</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Не може да отключите портфейла.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Request payment to ...</source>
        <translation type="unfinished">Изискване на плащане от ...</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Адрес:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Съобщение:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Портфейл</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Копиране на &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Копирай адрес</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Запиши изображение...</translation>
    </message>
    <message>
        <source>Request payment to %1</source>
        <translation>Изискване на плащане от %1</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Данни за плащането</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Съобщение</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(без съобщение)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Изпращане</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Настройки за контрол на монетите</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>астоматично избран</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Нямате достатъчно налични пари!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтове:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Такса:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>След такса:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Промяна:</translation>
    </message>
    <message>
        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
        <translation>Ако тази опция е активирана,но адресът на промяна е празен или невалиден,промяната ще бъде изпратена на новосъздаден адрес.</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Такса за транзакцията:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Избери...</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation>за килобайт</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Скрий</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Препоръчителна:</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>По избор:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Изпращане към повече от един получател</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Добави &amp;получател</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Изчисти всички полета от формуляра.</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>прах:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Изчисти</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Баланс:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Потвърдете изпращането</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>И&amp;зпрати</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Копиране на количеството</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Копиране на сумата</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Копирай такса</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Копирайте след такса</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Копиране на байтовете</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Копирай прахта:</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Промяна на копирането</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>Наистина ли искате да изпратите?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>или</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Такса</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Потвърждаване</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Изпрати</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Сумата трябва да е по-голяма от 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Сумата надвишава текущия баланс</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Сумата при добавяне на данък добавена стойност по %1 транзакцията надвишава сумата по вашата сметка.</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>Грешка при създаването на транзакция!</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Заявката за плащане е изтекла.</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>Внимание: Невалиден Биткойн адрес</translation>
    </message>
    <message>
        <source>Warning: Unknown change address</source>
        <translation>Внимание:Неизвестен адрес за промяна</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>С&amp;ума:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Плати &amp;На:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Име:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Изберете използван преди адрес</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Вмъкни от клипборда</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>Премахване на този запис</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Съобщение:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Плащане на:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Бележка:</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Не изключвайте компютъра докато този прозорец не изчезне.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Подпиши / Провери съобщение</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Подпиши</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Изберете използван преди адрес</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Вмъкни от клипборда</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Въведете съобщението тук</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Подпис</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Копиране на текущия подпис</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation>Подпишете съобщение като доказателство, че притежавате определен адрес</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Подпиши &amp;съобщение</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Изчисти</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Провери</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Bitcoin address</source>
        <translation>Проверете съобщение, за да сте сигурни че е подписано с определен Биткоин адрес</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>Потвърди &amp;съобщението</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Натиснете "Подписване на съобщение" за да създадете подпис</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Въведеният адрес е невалиден.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Моля проверете адреса и опитайте отново.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Въведеният адрес не може да се съпостави с валиден ключ.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Отключването на портфейла беше отменено.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Не е наличен частен ключ за въведеният адрес.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Подписването на съобщение беше неуспешно.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Съобщението е подписано.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Подписът не може да бъде декодиран.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Проверете подписа и опитайте отново.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Подписът не отговаря на комбинацията от съобщение и адрес.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Проверката на съобщението беше неуспешна.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Съобщението е потвърдено.</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>Килобайта в секунда</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>Подлежи на промяна до %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/непотвърдени</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>включена в %1 блока</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>източник</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Генериран</translation>
    </message>
    <message>
        <source>From</source>
        <translation>от</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>неизвестен</translation>
    </message>
    <message>
        <source>To</source>
        <translation>към</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>собствен адрес</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>само гледане</translation>
    </message>
    <message>
        <source>label</source>
        <translation>име</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>кредит</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>не е приет</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Дебит</translation>
    </message>
    <message>
        <source>Total debit</source>
        <translation>Общ дълг</translation>
    </message>
    <message>
        <source>Total credit</source>
        <translation>Общ дълг</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Такса</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Нетна сума</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Съобщение</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>Търговец</translation>
    </message>
    <message>
        <source>Generated coins must mature %1 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation>Генерираните монети трябва да отлежат %1 блока преди да могат да бъдат похарчени. Когато генерираш блока, той се разпространява в мрежата, за да се добави в блок-веригата. Ако не успее да се добави във веригата, неговия статус  ще се стане "неприет" и няма да може да се похарчи. Това е възможно да се случи случайно, ако друг възел генерира блок няколко секунди след твоя.</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>Информация за грешките</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Транзакция</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Количество</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Описание на транзакцията</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Подлежи на промяна до %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Непотвърдено</translation>
    </message>
    <message>
        <source>Confirming (%1 of %2 recommended confirmations)</source>
        <translation>Потвърждаване (%1 от %2 препоръчвани потвърждения)</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Потвърдени (%1 потвърждения)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Конфликтно</translation>
    </message>
    <message>
        <source>Immature (%1 confirmations, will be available after %2)</source>
        <translation>Неплатим (%1 потвърждения, ще бъде платим след %2)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Генерирана, но отхвърлена от мрежата</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Получени</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Получен от</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Изпратени на</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Плащане към себе си</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Емитирани</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>само гледане</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Състояние на транзакцията. Задръжте върху това поле за брой потвърждения.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Дата и час на получаване на транзакцията.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Вид транзакция.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Сума извадена или добавена към баланса.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Всички</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Днес</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Тази седмица</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Този месец</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Предния месец</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Тази година</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>От - до...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Получени</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Изпратени на</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Емитирани</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Други</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Минимална сума</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Копирайте адреса</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Копиране на &amp;етикета</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation>Копиране на &amp;сумата</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation>&amp;Копиране на &amp;ID на транзакцията</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;Редактирай име</translation>
    </message>
    <message>
        <source>&amp;Show transaction details</source>
        <translation type="unfinished">&amp;Подробности за транзакцията</translation>
    </message>
    <message>
        <source>Export Transaction History</source>
        <translation>Изнасяне историята на транзакциите</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>CSV файл (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Потвърдено</translation>
    </message>
    <message>
        <source>Watch-only</source>
        <translation>само гледане</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ИД</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Изнасянето се провали</translation>
    </message>
    <message>
        <source>Exporting Successful</source>
        <translation>Изнасянето е успешна</translation>
    </message>
    <message>
        <source>The transaction history was successfully saved to %1.</source>
        <translation>Историята с транзакциите беше успешно запазена в %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>От:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>до</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>Затвори портфейла</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Затвори всички портфейли</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>Създай нов портфейл</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>грешка</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Изпращане</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>Портфейл по подразбиране</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>Изнеси</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Изнеси данните в избрания раздел към файл</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Запазване на портфейла</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Информация за портфейла (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Неуспешно запазване на портфейла</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to %1.</source>
        <translation>Възникна грешка при запазването на информацията за портфейла в %1.</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to %1: %2</source>
        <translation>Възникна грешка при запазването на информацията за портфейла в %1: %2</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation>Успешно запазване на портфейла</translation>
    </message>
    <message>
        <source>The wallet data was successfully saved to %1.</source>
        <translation>Информацията за портфейла беше успешно запазена в %1.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Отказ</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>Желаете ли да пресъздадете базата данни с блокове сега?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Грешка в пускането на базата данни с блокове</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>грешка</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Провалено "слушане" на всеки порт. Използвайте -listen=0 ако искате това.</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Внасяне...</translation>
    </message>
    <message>
        <source>Loading P2P addresses...</source>
        <translation>Зареждане на адреси...</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Проверка на блоковете...</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>Това е експериментален софтуер.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Сумата на транзакцията е твърде малка</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Транзакцията е твърде голяма</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation>Проверка на портфейла...</translation>
    </message>
    <message>
        <source>Starting network threads...</source>
        <translation>Стартиране на мрежовите нишки...</translation>
    </message>
    <message>
        <source>The wallet will avoid paying less than the minimum relay fee.</source>
        <translation>Портфейлът няма да плаша по-малко от миналата такса за препредаване.</translation>
    </message>
    <message>
        <source>This is the minimum transaction fee you pay on every transaction.</source>
        <translation>Това е минималната такса за транзакция, която плащате за всяка транзакция.</translation>
    </message>
    <message>
        <source>This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Това е таксата за транзакцията която ще платите ако изпратите транзакция.</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>Сумите на транзакциите не могат да бъдат отрицателни</translation>
    </message>
    <message>
        <source>Transaction must have at least one recipient</source>
        <translation>Транзакцията трябва да има поне един получател.</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Недостатъчно средства</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Зареждане на блок индекса...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Зареждане на портфейла...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Преразглеждане на последовтелността от блокове...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Зареждането е завършено</translation>
    </message>
</context>
</TS>